@@ -57,7 +57,7 @@ class OpenPYXLReader(FileHandler):
         sheets = dict()
 
         try:
-            with load_workbook(self.file_path) as xls_file:
+            with load_workbook(self.file_path, data_only=True) as xls_file:
                 if self.flag_read_only and xls_file.read_only:
                     raise ReadOnlyError
 
