@@ -5,8 +5,8 @@ from pandas import DataFrame
 
 
 class JSONReader(FileHandler):
-    def __init__(self, file_path):
-        super().__init__(file_path=file_path)
+    def __init__(self, file_path, **kwargs):
+        super().__init__(file_path=file_path, **kwargs)
 
     def parse(self):
         if self.streams:
@@ -15,7 +15,7 @@ class JSONReader(FileHandler):
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None, **kwargs):
+    def __parse(self, handler=None, buffer=None):
         data = list()
         row_num = 0
         header = None
